@@ -2,7 +2,6 @@ import json
 
 import pytest
 
-from mythx_models.exceptions import ValidationError
 from mythx_models.response import Analysis, AnalysisSubmissionResponse
 from mythx_models.util import serialize_api_timestamp
 
@@ -30,9 +29,9 @@ def test_analysis_submission_from_valid_json():
     assert_analysis_data(DICT_DATA, resp.analysis)
 
 
-def test_analysis_submission_from_empty_json():
-    with pytest.raises(ValidationError):
-        AnalysisSubmissionResponse.from_json("{}")
+# def test_analysis_submission_from_empty_json():
+#     with pytest.raises(ValidationError):
+#         AnalysisSubmissionResponse.from_json("{}")
 
 
 def test_analysis_submission_from_valid_dict():
@@ -40,9 +39,9 @@ def test_analysis_submission_from_valid_dict():
     assert_analysis_data(DICT_DATA, resp.analysis)
 
 
-def test_analysis_submission_from_empty_dict():
-    with pytest.raises(ValidationError):
-        AnalysisSubmissionResponse.from_dict({})
+# def test_analysis_submission_from_empty_dict():
+#     with pytest.raises(ValidationError):
+#         AnalysisSubmissionResponse.from_dict({})
 
 
 def test_analysis_submission_to_dict():
